@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright (C) 2002-2003 Rochet Sylvain
+ *  Copyright (C) 2002-2004 Rochet Sylvain
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -472,7 +472,7 @@ void CallBack_PopupMenuPlayer(GtkWidget* widget)  {
 	if(! strcmp(action, "version") )  {
 
 		/* request version */
-		text = g_strdup_printf("!version %s\n", game->player[ get_player_slot_with_playerid(id) ].name);
+		text = g_strdup_printf("!version %s\n", global->player[ get_player_slot_with_playerid(id) ].name);
 		client_send(game->connectid, text, strlen(text));
 		g_free(text);
 	}
@@ -480,7 +480,7 @@ void CallBack_PopupMenuPlayer(GtkWidget* widget)  {
 	if(! strcmp(action, "date") )  {
 
 		/* request date */
-		text = g_strdup_printf("!date %s\n", game->player[ get_player_slot_with_playerid(id) ].name);
+		text = g_strdup_printf("!date %s\n", global->player[ get_player_slot_with_playerid(id) ].name);
 		client_send(game->connectid, text, strlen(text));
 		g_free(text);
 	}
@@ -488,7 +488,7 @@ void CallBack_PopupMenuPlayer(GtkWidget* widget)  {
 	if(! strcmp(action, "ping") )  {
 
 		/* request date */
-		text = g_strdup_printf("!ping %s\n", game->player[ get_player_slot_with_playerid(id) ].name);
+		text = g_strdup_printf("!ping %s\n", global->player[ get_player_slot_with_playerid(id) ].name);
 		client_send(game->connectid, text, strlen(text));
 		g_free(text);
 	}
@@ -522,21 +522,26 @@ void CallBack_menu_change_nickname(GtkWidget* widget)  {
 
 
 /* *** callback for the ok button of window change nickname */
-void CallBack_ok_button_changenick_window(GtkWidget* widget, GtkWidget *Win)  {
+void CallBack_response_changenick_window(GtkWidget* widget, gint response, 
+		GtkWidget *Win)  
+{
+	if(response == GTK_RESPONSE_OK)
+	{
+		GtkWidget *Entry = gtk_object_get_data(GTK_OBJECT(Win), "nickname");
+		guchar *nickname, *sendstr;
 
-	GtkWidget *Entry = gtk_object_get_data(GTK_OBJECT(Win), "nickname");
-	guchar *nickname, *sendstr;
+		nickname = g_strdup( gtk_entry_get_text(GTK_ENTRY( Entry ) )  );
+	
+		if(strcmp(global->player[ get_player_slot_with_playerid(game->my_playerid) ].name, nickname) )  
+		{
+			sendstr = g_strdup_printf(".n%s\n", nickname);
+			client_send(game->connectid, sendstr, strlen(sendstr) );
+			g_free(sendstr);
+		}
 
-	nickname = g_strdup( gtk_entry_get_text(GTK_ENTRY( Entry ) )  );
-
-	if(strcmp(game->player[ get_player_slot_with_playerid(game->my_playerid) ].name, nickname) )  {
-
-		sendstr = g_strdup_printf(".n%s\n", nickname);
-		client_send(game->connectid, sendstr, strlen(sendstr) );
-		g_free(sendstr);
+		g_free(nickname);
 	}
 
-	g_free(nickname);
 	gtk_widget_destroy(Win);
 }
 
@@ -673,8 +678,8 @@ void CallBack_trade_update_component(GtkWidget *button)  {
 
 		case TRADE_CURRENT_COMPONENT_ESTATE:
 
-			estateid = get_estateid_by_estatename( gtk_entry_get_text( gtk_object_get_data( GTK_OBJECT(button), "name_estate" ) )  );
-			target = get_playerid_by_playername( gtk_entry_get_text( gtk_object_get_data( GTK_OBJECT(button), "name_target_player" ) )  );
+			estateid = get_estateid_by_estatename( (guchar*)gtk_entry_get_text( gtk_object_get_data( GTK_OBJECT(button), "name_estate" ) )  );
+			target = get_playerid_by_playername( (guchar*)gtk_entry_get_text( gtk_object_get_data( GTK_OBJECT(button), "name_target_player" ) )  );
 
 			sendstr = g_strdup_printf(".Te%d:%d:%d\n", tradeid, estateid, target);
 			client_send(game->connectid, sendstr, strlen(sendstr));
@@ -683,8 +688,8 @@ void CallBack_trade_update_component(GtkWidget *button)  {
 
 		case TRADE_CURRENT_COMPONENT_MONEY:
 
-			from = get_playerid_by_playername( gtk_entry_get_text( gtk_object_get_data( GTK_OBJECT(button), "name_from_player" ) )  );
-			to = get_playerid_by_playername( gtk_entry_get_text( gtk_object_get_data( GTK_OBJECT(button), "name_to_player" ) )  );
+			from = get_playerid_by_playername( (guchar*)gtk_entry_get_text( gtk_object_get_data( GTK_OBJECT(button), "name_from_player" ) )  );
+			to = get_playerid_by_playername( (guchar*) gtk_entry_get_text( gtk_object_get_data( GTK_OBJECT(button), "name_to_player" ) )  );
 			money = atoi( gtk_entry_get_text( gtk_object_get_data( GTK_OBJECT(button), "amount_money" ) )  );
 
 			sendstr = g_strdup_printf(".Tm%d:%d:%d:%d\n", tradeid, from, to, money);
@@ -695,7 +700,7 @@ void CallBack_trade_update_component(GtkWidget *button)  {
 		case TRADE_CURRENT_COMPONENT_CARD:
 
 			cardid = atoi( gtk_entry_get_text( gtk_object_get_data( GTK_OBJECT(button), "name_card" ) )  );
-			target = get_playerid_by_playername( gtk_entry_get_text( gtk_object_get_data( GTK_OBJECT(button), "name_target_player" ) )  );
+			target = get_playerid_by_playername( (guchar*) gtk_entry_get_text( gtk_object_get_data( GTK_OBJECT(button), "name_target_player" ) )  );
 
 			sendstr = g_strdup_printf(".Tc%d:%d:%d\n", tradeid, cardid, target);
 			client_send(game->connectid, sendstr, strlen(sendstr));
@@ -831,7 +836,7 @@ void CallBack_EstateTree_SelectRow(GtkCTree *EstateTree,  GtkCTreeNode *Node)  {
 	if(game->estate[id].price)  {
 
 		if(game->estate[id].owner <= 0)  Text = g_strdup("Owner: no");
-		else  Text = g_strdup_printf("Owner: %s", game->player[ get_player_slot_with_playerid( game->estate[id].owner ) ].name);
+		else  Text = g_strdup_printf("Owner: %s", global->player[ get_player_slot_with_playerid( game->estate[id].owner ) ].name);
 
 		Alignment = gtk_alignment_new(0.0, 0.0, 0.0, 0.0);
 		gtk_box_pack_start(GTK_BOX(info), Alignment, FALSE, TRUE, 0);
