@@ -243,109 +243,6 @@ gint32 client_recv(gint32 id)
 
 		/* remove nasty CR */
 		if(buffer[i] == 13)  buffer[i] = ' ';
-
-		/* replace no ascii char */
-		if( buffer[i] > 127 )  {
-
-			switch(buffer[i])  {
-
-				case 161:  buffer[i] = '!';  break;
-				case 162:  buffer[i] = 'c';  break;
-				case 163:  buffer[i] = 'f';  break;
-				case 164:  buffer[i] = 'o';  break;
-				case 165:  buffer[i] = 'Y';  break;
-				case 166:  buffer[i] = '|';  break;
-				case 167:  buffer[i] = 'S';  break;
-				case 169:  buffer[i] = 'c';  break;
-				case 170:  buffer[i] = 'a';  break;
-				case 171:  buffer[i] = 'C';  break;
-				case 172:  buffer[i] = '-';  break;
-				case 173:  buffer[i] = '-';  break;
-				case 174:  buffer[i] = 'R';  break;
-				case 175:  buffer[i] = '-';  break;
-				case 176:  buffer[i] = 'o';  break;
-				case 177:  buffer[i] = '+';  break;
-				case 178:  buffer[i] = '2';  break;
-				case 179:  buffer[i] = '3';  break;
-				case 181:  buffer[i] = 'u';  break;
-				case 182:  buffer[i] = 'P';  break;
-				case 183:  buffer[i] = '-';  break;
-				case 185:  buffer[i] = '1';  break;
-				case 186:  buffer[i] = 'o';  break;
-				case 187:  buffer[i] = 'D';  break;
-				case 191:  buffer[i] = '?';  break;
-				case 192:  buffer[i] = 'A';  break;
-				case 193:  buffer[i] = 'A';  break;
-				case 194:  buffer[i] = 'A';  break;
-				case 195:  buffer[i] = 'A';  break;
-				case 196:  buffer[i] = 'A';  break;
-				case 197:  buffer[i] = 'A';  break;
-				case 198:  buffer[i] = 'F';  break;
-				case 199:  buffer[i] = 'C';  break;
-				case 200:  buffer[i] = 'E';  break;
-				case 201:  buffer[i] = 'E';  break;
-				case 202:  buffer[i] = 'E';  break;
-				case 203:  buffer[i] = 'E';  break;
-				case 204:  buffer[i] = 'I';  break;
-				case 205:  buffer[i] = 'I';  break;
-				case 206:  buffer[i] = 'I';  break;
-				case 207:  buffer[i] = 'I';  break;
-				case 208:  buffer[i] = 'D';  break;
-				case 209:  buffer[i] = 'N';  break;
-				case 210:  buffer[i] = 'O';  break;
-				case 211:  buffer[i] = 'O';  break;
-				case 212:  buffer[i] = 'O';  break;
-				case 213:  buffer[i] = 'O';  break;
-				case 214:  buffer[i] = 'O';  break;
-				case 215:  buffer[i] = 'x';  break;
-				case 216:  buffer[i] = 'O';  break;
-				case 217:  buffer[i] = 'U';  break;
-				case 218:  buffer[i] = 'U';  break;
-				case 219:  buffer[i] = 'U';  break;
-				case 220:  buffer[i] = 'U';  break;
-				case 221:  buffer[i] = 'Y';  break;
-				case 222:  buffer[i] = 'p';  break;
-				case 223:  buffer[i] = 'B';  break;
-				case 224:  buffer[i] = 'a';  break;
-				case 225:  buffer[i] = 'a';  break;
-				case 226:  buffer[i] = 'a';  break;
-				case 227:  buffer[i] = 'a';  break;
-				case 228:  buffer[i] = 'a';  break;
-				case 229:  buffer[i] = 'a';  break;
-				case 230:  buffer[i] = 'e';  break;
-				case 231:  buffer[i] = 'c';  break;
-				case 232:  buffer[i] = 'e';  break;
-				case 233:  buffer[i] = 'e';  break;
-				case 234:  buffer[i] = 'e';  break;
-				case 235:  buffer[i] = 'e';  break;
-				case 236:  buffer[i] = 'i';  break;
-				case 237:  buffer[i] = 'i';  break;
-				case 238:  buffer[i] = 'i';  break;
-				case 239:  buffer[i] = 'i';  break;
-				case 240:  buffer[i] = 'o';  break;
-				case 241:  buffer[i] = 'n';  break;
-				case 242:  buffer[i] = 'o';  break;
-				case 243:  buffer[i] = 'o';  break;
-				case 244:  buffer[i] = 'o';  break;
-				case 245:  buffer[i] = 'o';  break;
-				case 246:  buffer[i] = 'o';  break;
-				case 247:  buffer[i] = '%';  break;
-				case 248:  buffer[i] = 'o';  break;
-				case 249:  buffer[i] = 'u';  break;
-				case 250:  buffer[i] = 'u';  break;
-				case 251:  buffer[i] = 'u';  break;
-				case 252:  buffer[i] = 'u';  break;
-				case 253:  buffer[i] = 'y';  break;
-				case 254:  buffer[i] = 'p';  break;
-				case 255:  buffer[i] = 'y';  break;
-				default:
-#if DEBUG
-					fprintf(stderr, "[WARNING] No UTF8 chr from server: (%c -> %d)\n", buffer[i], buffer[i]);
-#endif
-					buffer[i] = ' ';
-					break;
-			}
-		}
 	}
 
 	/* concatenate data */
