@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright (C) 2002-2003 Rochet Sylvain
+ *  Copyright (C) 2002-2004 Rochet Sylvain
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -229,11 +229,12 @@ void trade_rebuild_playerlist(guint32 tradeslot)  {
 
 	for(i = 0 ; i < MAX_PLAYERS ; i++)  {
 
-		if(! game->player[i].playerid) continue;
+		if(! global->player[i].playerid) continue;
+		if(global->player[i].game != game->gameid)  continue;
 		if(! game->trade[tradeslot].player[i][TRADE_PLAYER_PARTICIPATE]) continue;
 
-		txt[0] = game->player[i].name;
-		txt[1] = g_strdup_printf("%d", game->player[i].playerid);
+		txt[0] = global->player[i].name;
+		txt[1] = g_strdup_printf("%d", global->player[i].playerid);
 		row = gtk_clist_append(GTK_CLIST(PlayerCList), txt);
 		g_free(txt[1]);
 
@@ -386,8 +387,9 @@ void trade_rebuild_subcomponent(guint32 tradeslot)  {
 			list = NULL;
 			for(i = 0 ; i < MAX_PLAYERS ; i++)  {
 
-				if(!game->player[i].playerid)  continue;
-				list = g_list_append(list, game->player[i].name);
+				if(!global->player[i].playerid)  continue;
+				if(global->player[i].game != game->gameid)  continue;
+				list = g_list_append(list, global->player[i].name);
 			}
 			if(list)  {
 				gtk_combo_set_popdown_strings(GTK_COMBO(Combo), list);
@@ -429,8 +431,9 @@ void trade_rebuild_subcomponent(guint32 tradeslot)  {
 			list = NULL;
 			for(i = 0 ; i < MAX_PLAYERS ; i++)  {
 
-				if(!game->player[i].playerid)  continue;
-				list = g_list_append(list, game->player[i].name);
+				if(!global->player[i].playerid)  continue;
+				if(global->player[i].game != game->gameid)  continue;
+				list = g_list_append(list, global->player[i].name);
 			}
 			if(list)  {
 				gtk_combo_set_popdown_strings(GTK_COMBO(Combo), list);
@@ -450,8 +453,9 @@ void trade_rebuild_subcomponent(guint32 tradeslot)  {
 			list = NULL;
 			for(i = 0 ; i < MAX_PLAYERS ; i++)  {
 
-				if(!game->player[i].playerid)  continue;
-				list = g_list_append(list, game->player[i].name);
+				if(!global->player[i].playerid)  continue;
+				if(global->player[i].game != game->gameid)  continue;
+				list = g_list_append(list, global->player[i].name);
 			}
 			if(list)  {
 				gtk_combo_set_popdown_strings(GTK_COMBO(Combo), list);
@@ -514,8 +518,9 @@ void trade_rebuild_subcomponent(guint32 tradeslot)  {
 			list = NULL;
 			for(i = 0 ; i < MAX_PLAYERS ; i++)  {
 
-				if(!game->player[i].playerid)  continue;
-				list = g_list_append(list, game->player[i].name);
+				if(!global->player[i].playerid)  continue;
+				if(global->player[i].game != game->gameid)  continue;
+				list = g_list_append(list, global->player[i].name);
 			}
 			if(list)  {
 				gtk_combo_set_popdown_strings(GTK_COMBO(Combo), list);
@@ -581,9 +586,9 @@ void trade_update_card(gint32 tradeid, gint32 cardid, gint32 targetplayer)  {
 	}
 
 	txt[0] = g_strdup("CARD :");
-	txt[1] = game->player[ get_player_slot_with_playerid( game->card[ get_card_slot_with_cardid(cardid)  ].owner ) ].name;
+	txt[1] = global->player[ get_player_slot_with_playerid( game->card[ get_card_slot_with_cardid(cardid)  ].owner ) ].name;
 	txt[2] = g_strdup("gives");
-	txt[3] = game->player[ get_player_slot_with_playerid(targetplayer) ].name;
+	txt[3] = global->player[ get_player_slot_with_playerid(targetplayer) ].name;
 	txt[4] = cardname;
 	txt[5] = g_strdup("card");
 	txt[6] = g_strdup_printf("%d", game->card[ get_card_slot_with_cardid(cardid)  ].owner);
@@ -636,9 +641,9 @@ void trade_update_estate(gint32 tradeid, gint32 estateid, gint32 targetplayer)
 	if(targetplayer < 0) return;
 
 	txt[0] = g_strdup("ESTATE :");
-	txt[1] = game->player[ get_player_slot_with_playerid( game->estate[estateid].owner) ].name;
+	txt[1] = global->player[ get_player_slot_with_playerid( game->estate[estateid].owner) ].name;
 	txt[2] = g_strdup("gives");
-	txt[3] = game->player[ get_player_slot_with_playerid(targetplayer) ].name;
+	txt[3] = global->player[ get_player_slot_with_playerid(targetplayer) ].name;
 	txt[4] = estatename;
 	txt[5] = g_strdup("estate");
 	txt[6] = g_strdup_printf("%d", game->estate[estateid].owner);
@@ -667,8 +672,8 @@ void trade_update_money(gint32 tradeid, gint32 playerfrom, gint32 playerto, gint
 
 	tradeslot = get_trade_slot_with_tradeid(tradeid);
 	ProposalCList = game->trade[tradeslot].ProposalCList;
-	from = game->player[ get_player_slot_with_playerid(playerfrom) ].name;
-	to = game->player[ get_player_slot_with_playerid(playerto) ].name;
+	from = global->player[ get_player_slot_with_playerid(playerfrom) ].name;
+	to = global->player[ get_player_slot_with_playerid(playerto) ].name;
 
 	/* remove all money proposal if same playerfrom and same playerto */
 	text[0] = g_malloc0(8192);
