@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright (C) 2002-2003 Rochet Sylvain
+ *  Copyright (C) 2002-2004 Rochet Sylvain
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-
+#define GTK_ENABLE_BROKEN = 1
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -375,16 +375,17 @@ void xmlparse_estateupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 	if(owner_mortgage_changed)  {
 
-		t = game->estate[id].owner;		
+		t = game->estate[id].owner;
 		u = game->estate[id].mortgaged;
 
 		/* reset unowned cards of this estate to all players */
 		for(i = 0 ; i < MAX_PLAYERS ; i++)  {
 
-			if(! game->player[i].playerid) continue;
+			if(! global->player[i].playerid) continue;
+			if(global->player[i].game != game->gameid)  continue;
 
-			frame = game->player[i].playerlist_cards_frame;
-			pic = game->player[i].playerlist_cards_pic[ get_playerlistcard_id_with_estate(id) ];
+			frame = global->player[i].playerlist_cards_frame;
+			pic = global->player[i].playerlist_cards_pic[ get_playerlistcard_id_with_estate(id) ];
 
 			pic_set_alpha(frame, pic, data->playerlist_cards_alphaunowned);
 		}
@@ -393,7 +394,7 @@ void xmlparse_estateupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 			/* star */
 			frame = game->board_frame;
-			star = game->player[ get_player_slot_with_playerid(t) ].buffer_star;
+			star = global->player[ get_player_slot_with_playerid(t) ].buffer_star;
 
 			pic = game->estate[id].star_alpha;
 			pic_set_width(frame, pic, data->pngfile_star_width[star]);
@@ -407,8 +408,8 @@ void xmlparse_estateupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 			pic_show(frame, pic);
 
 			/* playerlist card */
-			frame = game->player[ get_player_slot_with_playerid(t) ].playerlist_cards_frame;
-			pic = game->player[ get_player_slot_with_playerid(t) ].playerlist_cards_pic[ get_playerlistcard_id_with_estate(id) ];
+			frame = global->player[ get_player_slot_with_playerid(t) ].playerlist_cards_frame;
+			pic = global->player[ get_player_slot_with_playerid(t) ].playerlist_cards_pic[ get_playerlistcard_id_with_estate(id) ];
 
 			pic_set_bgcolor(frame, pic, data->playerlist_cards_cardbgcolor);
 			pic_set_alpha(frame, pic, data->playerlist_cards_alphaowned);
@@ -417,7 +418,7 @@ void xmlparse_estateupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 			/* star */
 			frame = game->board_frame;
-			star = game->player[ get_player_slot_with_playerid(t) ].buffer_star;
+			star = global->player[ get_player_slot_with_playerid(t) ].buffer_star;
 
 			pic = game->estate[id].star_alpha;
 			pic_set_width(frame, pic, data->pngfile_star_m_width[star]);
@@ -431,8 +432,8 @@ void xmlparse_estateupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 			pic_show(frame, pic);
 
 			/* playerlist card */
-			frame = game->player[ get_player_slot_with_playerid(t) ].playerlist_cards_frame;
-			pic = game->player[ get_player_slot_with_playerid(t) ].playerlist_cards_pic[ get_playerlistcard_id_with_estate(id) ];
+			frame = global->player[ get_player_slot_with_playerid(t) ].playerlist_cards_frame;
+			pic = global->player[ get_player_slot_with_playerid(t) ].playerlist_cards_pic[ get_playerlistcard_id_with_estate(id) ];
 
 			pic_set_bgcolor(frame, pic, data->playerlist_cards_cardbgcolormortgage);
 			pic_set_alpha(frame, pic, data->playerlist_cards_alphamortgage);
@@ -510,7 +511,7 @@ void xmlparse_estateupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 		g_free(tmp);
 	}
 
-	tmp = xmlGetProp(cur, "mortgageprice"); 
+	tmp = xmlGetProp(cur, "mortgageprice");
 	if(tmp)  {
 		game->estate[id].mortgageprice = atoi(tmp);
 		g_free(tmp);
@@ -565,7 +566,7 @@ void xmlparse_estateupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 	}
 
 	for(i = 0 ; i <= 5 ; i++) {
-   
+
 		key = g_strdup_printf("rent%d", i);
 		tmp = xmlGetProp(cur, key);
 
@@ -582,7 +583,7 @@ void xmlparse_estateupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 void xmlparse_playerupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
-	guint32 playerid, i, gam = 0;
+	gint32 playerid, i;
 	gint8 id;
 	guchar *tmp;
 	GtkWidget *Combo, *StartButton, *Button;
@@ -597,42 +598,45 @@ void xmlparse_playerupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 	id = get_player_slot_with_playerid(playerid);
 
+	/* create new player */
+	if(id < 0)  {
+		if(game->status <= GAME_STATUS_CONFIG)  {
+
+			if(! game_get_valid_player_slot(&id) ) return;
+
+			memset(&global->player[id], 0, sizeof(_player) );
+			global->player[id].playerid = playerid;
+			game->nb_players++;
+		}
+		else return;
+	}
+
+	if(id >= 0 && game->status > GAME_STATUS_CONFIG && global->player[id].game != game->gameid) return;
+
 	tmp = xmlGetProp(cur, "game");
 	if(tmp)  {
 
-		gam = atoi(tmp);
+		global->player[id].game = atoi(tmp);
 		g_free(tmp);
-
-		if(gam < 0  ||  gam != game->gameid)  return;
 	}
 
-	/* create new player */
-	if(id < 0)  {
-
-		if(! game_get_valid_player_slot(&id) ) return;
-
-		memset(&game->player[id], 0, sizeof(_player) );
-		game->player[id].playerid = playerid;
-		game->player[id].game = gam;
-		game->nb_players++;
-	}
 
 	tmp = xmlGetProp(cur, "host");
 	if(tmp)  {
 
-		if(game->player[id].host) g_free(game->player[id].host);
-		game->player[id].host = tmp;
+		if(global->player[id].host) g_free(global->player[id].host);
+		global->player[id].host = tmp;
 	}
 
 	tmp = xmlGetProp(cur, "master");
 	if(tmp)  {
 
-		game->player[id].master = atoi(tmp);
+		global->player[id].master = atoi(tmp);
 		g_free(tmp);
 
-		if(game->player[id].master  &&  game->my_playerid == playerid)
+		if(global->player[id].master  &&  game->my_playerid == playerid)
 			game->i_am_the_master = TRUE;
-		if(!game->player[id].master  &&  game->my_playerid == playerid)
+		if(!global->player[id].master  &&  game->my_playerid == playerid)
 			game->i_am_the_master = FALSE;
 
 		/* set sensitive mode of start button */
@@ -646,20 +650,25 @@ void xmlparse_playerupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 	tmp = xmlGetProp(cur, "image");
 	if(tmp)  {
 
-		if(game->player[id].image) g_free(game->player[id].image);
-		game->player[id].image = tmp;
+		if(global->player[id].image) g_free(global->player[id].image);
+		global->player[id].image = tmp;
 	}
 
 	tmp = xmlGetProp(cur, "name");
 	if(tmp)  {
 
-		if(game->player[id].name) g_free(game->player[id].name);
-		game->player[id].name = g_strndup(tmp, MAX_LENGTH_NICK);
+		if(global->player[id].name) g_free(global->player[id].name);
+		global->player[id].name = g_strndup(tmp, MAX_LENGTH_NICK);
 		g_free(tmp);
 
+		if(! strcmp(global->player[id].name, "_metaserver_"))  {
+			game_delete_player(id);
+			return;
+		}
+
 		/* playerlist name */
-		if(game->player[id].playerlist_LabelNamePlayer)
-			gtk_label_set_text(GTK_LABEL(game->player[id].playerlist_LabelNamePlayer), game->player[id].name);
+		if(global->player[id].playerlist_LabelNamePlayer)
+			gtk_label_set_text(GTK_LABEL(global->player[id].playerlist_LabelNamePlayer), global->player[id].name);
 
 		/* popdown string trade combo */
 		Combo = gtk_object_get_data(GTK_OBJECT(global->MainVerticalBox), "trade_combo_listplayer");
@@ -668,10 +677,11 @@ void xmlparse_playerupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 			list = NULL;
 			for(i = 0 ; i < MAX_PLAYERS ; i++)  {
 
-				if(! game->player[i].playerid) continue;
-				if(game->player[i].playerid  ==  game->my_playerid) continue;
-	
-				list = g_list_append(list, game->player[i].name);
+				if(! global->player[i].playerid) continue;
+				if(global->player[i].game != game->gameid)  continue;
+				if(global->player[i].playerid  ==  game->my_playerid) continue;
+
+				list = g_list_append(list, global->player[i].name);
 			}
 			gtk_combo_set_popdown_strings(GTK_COMBO(Combo), list);
 			g_list_free(list);
@@ -697,23 +707,23 @@ void xmlparse_playerupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 	tmp = xmlGetProp(cur, "money");
 	if(tmp)  {
 
-		game->player[id].money = atoi(tmp);
+		global->player[id].money = atoi(tmp);
 
-		if(game->player[id].playerlist_LabelMoneyPlayer)
-			gtk_label_set_text(GTK_LABEL(game->player[id].playerlist_LabelMoneyPlayer), tmp);
+		if(global->player[id].playerlist_LabelMoneyPlayer)
+			gtk_label_set_text(GTK_LABEL(global->player[id].playerlist_LabelMoneyPlayer), tmp);
 		g_free(tmp);
 	}
 
 	tmp = xmlGetProp(cur, "location");
 	if(tmp)  {
 
-		game->player[id].location_to = atoi(tmp);
+		global->player[id].location_to = atoi(tmp);
 		g_free(tmp);
 	}
 
 	tmp = xmlGetProp(cur, "jailed");
 	if(tmp)  {
-		game->player[id].jailed = atoi(tmp);
+		global->player[id].jailed = atoi(tmp);
 		g_free(tmp);
 
 		game_update_tokens();
@@ -721,61 +731,61 @@ void xmlparse_playerupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 	tmp = xmlGetProp(cur, "directmove");
 	if(tmp)  {
-		game->player[id].directmove = atoi(tmp);
+		global->player[id].directmove = atoi(tmp);
 		g_free(tmp);
 
-		game_start_move_token(game->player[id].playerid);
+		game_start_move_token(global->player[id].playerid);
 	}
 
 	tmp = xmlGetProp(cur, "bankrupt");
 	if(tmp)  {
-		game->player[id].bankrupt = atoi(tmp);
+		global->player[id].bankrupt = atoi(tmp);
 		g_free(tmp);
 
 		/* remove token */
-		if(game->player[id].bankrupt)
-			pic_unshow(game->board_frame, game->player[id].token_pic);
+		if(global->player[id].bankrupt)
+			pic_unshow(game->board_frame, global->player[id].token_pic);
 	}
 
 	tmp = xmlGetProp(cur, "hasturn");
 	if(tmp)  {
-		game->player[id].hasturn = atoi(tmp);
+		global->player[id].hasturn = atoi(tmp);
 		g_free(tmp);
 
 		/* set has turn attributes */
-		if(game->player[id].hasturn)  {
+		if(global->player[id].hasturn)  {
 
-			if(game->player[id].playerlist_LabelNamePlayer)  {
+			if(global->player[id].playerlist_LabelNamePlayer)  {
 
-				gtk_widget_set_style( gtk_object_get_data(GTK_OBJECT(game->player[id].playerlist_AlignementNamePlayer), "namelabel") ,  global->style_player_turn);
-				gtk_widget_set_style( gtk_object_get_data(GTK_OBJECT(game->player[id].playerlist_AlignementMoneyPlayer), "moneylabel") ,  global->style_player_turn);
+				gtk_widget_set_style( gtk_object_get_data(GTK_OBJECT(global->player[id].playerlist_AlignementNamePlayer), "namelabel") ,  global->style_player_turn);
+				gtk_widget_set_style( gtk_object_get_data(GTK_OBJECT(global->player[id].playerlist_AlignementMoneyPlayer), "moneylabel") ,  global->style_player_turn);
 			}
 
-			pic_unset_alpha(game->board_frame, game->player[id].token_pic);
+			pic_unset_alpha(game->board_frame, global->player[id].token_pic);
 		}
 		else  {
 
-			if(game->player[id].playerlist_LabelNamePlayer)  {
+			if(global->player[id].playerlist_LabelNamePlayer)  {
 
-				gtk_widget_set_style( gtk_object_get_data(GTK_OBJECT(game->player[id].playerlist_AlignementNamePlayer), "namelabel") ,  global->style_player_normal);
-				gtk_widget_set_style( gtk_object_get_data(GTK_OBJECT(game->player[id].playerlist_AlignementMoneyPlayer), "moneylabel") ,  global->style_player_normal);
+				gtk_widget_set_style( gtk_object_get_data(GTK_OBJECT(global->player[id].playerlist_AlignementNamePlayer), "namelabel") ,  global->style_player_normal);
+				gtk_widget_set_style( gtk_object_get_data(GTK_OBJECT(global->player[id].playerlist_AlignementMoneyPlayer), "moneylabel") ,  global->style_player_normal);
 			}
-			
+
 			if(config->game_token_transparency)
-				pic_set_alpha(game->board_frame, game->player[id].token_pic, 0x7f);
+				pic_set_alpha(game->board_frame, global->player[id].token_pic, 0x7f);
 		}
 	}
 
 	tmp = xmlGetProp(cur, "can_roll");
 	if(tmp)  {
-		game->player[id].can_roll = atoi(tmp);
+		global->player[id].can_roll = atoi(tmp);
 		g_free(tmp);
 
 		if(game->status == GAME_STATUS_RUN)  {
 
 			Button = gtk_object_get_data(GTK_OBJECT(game->CommandsBox), "roll_button");
 
-			if(game->player[id].can_roll)
+			if(global->player[id].can_roll)
 				gtk_widget_show_all(Button);
 			else
 				gtk_widget_hide(Button);
@@ -784,7 +794,7 @@ void xmlparse_playerupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 	tmp = xmlGetProp(cur, "can_buyestate");
 	if(tmp)  {
-		game->player[id].can_buyestate = atoi(tmp);
+		global->player[id].can_buyestate = atoi(tmp);
 		g_free(tmp);
 	}
 
@@ -797,6 +807,10 @@ void xmlparse_playerupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 void xmlparse_auctionupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 	GtkWidget *text, *entry, *box;
+	GtkTextBuffer *textbuff;
+	GtkTextIter textiter;
+	GtkTextMark *textmark;
+
 	guint32 actor = 0, auctionid, estateid, highbid = 0, highbidder, len, status;
 	guchar *ptr, *message, *tmp;
 
@@ -828,8 +842,14 @@ void xmlparse_auctionupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 		ptr = g_strdup_printf("%d", auctionid);
 		gtk_object_set_data_full(GTK_OBJECT(entry), "auctionid", ptr, g_free);
 
-		message = g_strdup_printf("%s auction estate %s", game->player[ get_player_slot_with_playerid( actor ) ].name, game->estate[ estateid ].name);
-		gtk_text_insert(GTK_TEXT(text), NULL, NULL, NULL, message, strlen(message) );
+		message = g_strdup_printf("%s auction estate %s", global->player[ get_player_slot_with_playerid( actor ) ].name, game->estate[ estateid ].name);
+
+		textbuff = gtk_text_view_get_buffer(GTK_TEXT_VIEW(text));
+		gtk_text_buffer_get_end_iter(textbuff, &textiter);
+		gtk_text_buffer_insert(textbuff, &textiter, message, strlen(message));
+		gtk_text_buffer_insert(textbuff, &textiter, "\n", -1);
+
+
 		g_free(message);
 	}
 
@@ -847,14 +867,18 @@ void xmlparse_auctionupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 		highbidder = atoi(tmp);
 		g_free(tmp);
 
-		message = g_strdup_printf("%s bid %d", game->player[ get_player_slot_with_playerid(highbidder) ].name, highbid);
+		message = g_strdup_printf("%s bid %d", global->player[ get_player_slot_with_playerid(highbidder) ].name, highbid);
 
 		text = gtk_object_get_data(GTK_OBJECT(game->BoardCenter), "auction_text");
 
-		len = gtk_text_get_length( GTK_TEXT(text) );
-		gtk_text_set_point( GTK_TEXT(text), len);
-		if(len > 0)  gtk_text_insert(GTK_TEXT(text), NULL, NULL, NULL, "\n", 1);
-		gtk_text_insert(GTK_TEXT(text), NULL, NULL, NULL, message, strlen(message) );
+		textbuff = gtk_text_view_get_buffer(GTK_TEXT_VIEW(text));
+		gtk_text_buffer_get_end_iter(textbuff, &textiter);
+		gtk_text_buffer_insert(textbuff, &textiter, message, strlen(message));
+		gtk_text_buffer_insert(textbuff, &textiter, "\n", -1);
+
+		/* Scroll the text */
+		textmark = gtk_text_buffer_get_mark(textbuff, "endmark");
+		gtk_text_view_scroll_to_mark(GTK_TEXT_VIEW(text), textmark, 0.0, FALSE, 0.0, 0.0);
 
 		g_free(message);
 	}
@@ -871,8 +895,15 @@ void xmlparse_auctionupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 			case 1:
 				text = gtk_object_get_data(GTK_OBJECT(game->BoardCenter), "auction_text");
 
-				message = g_strdup("\n<- going once ->");
-				gtk_text_insert(GTK_TEXT(text), NULL, NULL, NULL, message, strlen(message) );
+				message = g_strdup("<- going once ->");
+				textbuff = gtk_text_view_get_buffer(GTK_TEXT_VIEW(text));
+				gtk_text_buffer_get_end_iter(textbuff, &textiter);
+				gtk_text_buffer_insert(textbuff, &textiter, message, strlen(message));
+				gtk_text_buffer_insert(textbuff, &textiter, "\n", -1);
+				/* Scroll the text */
+				textmark = gtk_text_buffer_get_mark(textbuff, "endmark");
+				gtk_text_view_scroll_to_mark(GTK_TEXT_VIEW(text), textmark, 0.0, FALSE, 0.0, 0.0);
+
 				g_free(message);
 				break;
 
@@ -880,7 +911,14 @@ void xmlparse_auctionupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 				text = gtk_object_get_data(GTK_OBJECT(game->BoardCenter), "auction_text");
 
 				message = g_strdup("\n<- going twice ->");
-				gtk_text_insert(GTK_TEXT(text), NULL, NULL, NULL, message, strlen(message) );
+				textbuff = gtk_text_view_get_buffer(GTK_TEXT_VIEW(text));
+				gtk_text_buffer_get_end_iter(textbuff, &textiter);
+				gtk_text_buffer_insert(textbuff, &textiter, message, strlen(message));
+				gtk_text_buffer_insert(textbuff, &textiter, "\n", -1);
+				/* Scroll the text */
+				textmark = gtk_text_buffer_get_mark(textbuff, "endmark");
+				gtk_text_view_scroll_to_mark(GTK_TEXT_VIEW(text), textmark, 0.0, FALSE, 0.0, 0.0);
+
 				g_free(message);
 				break;
 
@@ -948,7 +986,7 @@ void xmlparse_display(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 			caption = xmlGetProp(cur2, "caption");
 			command = xmlGetProp(cur2, "command");
 
-			tmp = xmlGetProp(cur2, "enabled");		
+			tmp = xmlGetProp(cur2, "enabled");
 			enable = atoi(tmp);
 			g_free(tmp);
 
@@ -1282,12 +1320,7 @@ void xmlparse_deleteplayer(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 	if(id < 0)  return;
 
 	/* delete a player */
-	if(game->player[id].name) g_free(game->player[id].name);
-	if(game->player[id].host) g_free(game->player[id].host);
-	if(game->player[id].image) g_free(game->player[id].image);
-	memset(&game->player[id], 0, sizeof(_player) );
-	game->nb_players--;
-
+	game_delete_player(id);
 	game_buildplayerlist();
 }
 
